@@ -27,12 +27,13 @@ Alternate setup with dbus (much faster but incomplete):
 __usage__ = """
 usage:
 
-- Just use your gesture to call up the command wheel when you want to call one of your included programs.
+- call "pyrad.py" to start and show pyRad and "pyrad.py --quit" to shutdown the process in the background. "pyrad.py --help" shows the usage. "pyrad.py --daemon" starts pyRad without showing the GUI.
+- In systemsettings add the mouse gesture to call D-Bus: Program: org.kde.pyRad ; Object: /MainApplication ; Function: newInstance
+- Use your gesture to call up the command wheel when you want to call one of your included programs.
 - Left-click the program to start it. You can also press the key shown in the programs tooltip for the same effect. 
 - Right-click an item to edit it. Middle-click an item to add a new one after it (clockwise).
 - Make folders by using the action [("kreversi", None), ("icon", "action"), ("icon2", "action2"), ...].
-  Actions are simply the commands you'd use on the commandline (no shell scripting though).
-- call "pyrad.py --quit" to shutdown the process in the background. "pyrad.py --help" shows the usage. "pyrad.py --daemon" starts pyRad if without showing the GUI.
+  Actions are simply the commands you'd use on the commandline (there's no shell scripting though, except via `bash -c "for i in 1 2 3; do echo $i; done"`).
 
 """
 
@@ -98,7 +99,7 @@ __copyright__ = """pyRad - a wheel type command menu.
 ### Constants ###
 
 #: The PyRad version identifier
-__version__ = "0.4.0"
+__version__ = "0.4.2"
 appName = "pyRad"
 
 ### Commandline handling ###
