@@ -341,7 +341,10 @@ class Rad(QWidget):
             # because it needs the position in the circle.
             if SELECTION_KEYS_ORDERED[len(circle):]: 
                 key = SELECTION_KEYS_ORDERED[len(circle)]
-                toolTip =  key + " - " + str(action)
+                if action is not None and action.startswith("["):
+                    toolTip =  key + " - " + ", ".join([act for ico,act in eval(action) if act])
+                else: 
+                    toolTip =  key + " - " + str(action)
             else:
                 toolTip = str(action)
             label.setToolTip(toolTip)
